<?php

/**
 * @file
 * Deploy functions for Joinup.
 *
 * This should only contain update functions that rely on the Drupal API and
 * need to run _after_ the configuration is imported.
 *
 * This is applicable in most cases. However, in case the update code enables
 * some functionality that is required for configuration to be successfully
 * imported, it should instead be placed in joinup_core.post_update.php.
 */

declare(strict_types = 1);

use Drupal\joinup_user\JoinupUserDefaultAvatarImageHelper;

/**
 * Revert removal of collection that was lost.
 */
function joinup_core_deploy_0109101(): void {
  $ntriples = <<<EOF
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/collection/content_creation>	"only_members" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"IMAPS" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/language/default>	"1" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/1999/02/22-rdf-syntax-ns#type>	<http://www.w3.org/ns/dcat#Catalog> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/5fe7b050-1a31-43a0-94c5-8a23003eba70> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"simaps" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/44d6d394-1c00-4ef3-9563-6f4066e8871e> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"organisational" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/collection/field_newsletter/service_id>	"0"^^<http://www.w3.org/2001/XMLSchema#integer> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://purl.org/dc/terms/RightsStatement>	"false"^^<http://www.w3.org/2001/XMLSchema#boolean> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/owner/uid>	"700890"^^<http://www.w3.org/2001/XMLSchema#integer> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"technical" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/a60a2758-28d0-441c-b1ea-68a6a178fd0f> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/ca2aafe3-e32c-4a3b-8c94-c8113847fcbc> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/site-pinned>	"false"^^<http://www.w3.org/2001/XMLSchema#boolean> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"structural" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/f586affc-6701-46ac-b860-e1a28651ff26> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"structural interoperability" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/e57137e7-0781-43c1-a974-07b646e01a32> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/language>	"en"@en .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"IATs" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://xmlns.com/foaf/0.1/Image>	"573736"^^<http://www.w3.org/2001/XMLSchema#string> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/site-featured>	"false"^^<http://www.w3.org/2001/XMLSchema#boolean> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/language/translation_status>	"1"@en .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://purl.org/dc/terms/publisher>	<http://data.europa.eu/w21/10ec5d16-3753-4eea-a921-1bed604b12a9> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/af8c0501-b85c-4405-9389-856cbea70271> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"behavioural interoperability" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"interoperability" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://purl.org/dc/terms/issued>	"2018-05-28T10:00:30+02:00"^^<http://www.w3.org/2001/XMLSchema#dateTime> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"SIQAT" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/8f67de7b-9478-49fa-b665-833dcb82e255> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"timaps" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/vocabulary/topic>	<http://joinup.eu/ontology/topic#egovernment> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/language/translation_author>	"700890"@en .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/28bb4f0d-931e-4d2e-ba55-546d10ca6ebd> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/bf99e6e4-8530-44b9-a69e-4433366692ec> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/ar/workflow_status>	"validated"^^<http://www.w3.org/2001/XMLSchema#string> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/language/translation_source>	"und"@en .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"governance" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"governance interoperability" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/d7fc7333-7911-4c97-8faa-ee58eaefcdfd> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/badeee45-24e0-41f0-be4b-cb8f5e7267b2> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"GIQAT" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/collection/field_newsletter/enabled>	"false"^^<http://www.w3.org/2001/XMLSchema#boolean> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://purl.org/dc/terms/description>	"""<p><em><strong>Start your own assessment with&nbsp;</strong><a href=\"https://ec.europa.eu/eusurvey/runner/IMAPS_v_2_2_0\">IMAPS&nbsp;v2.2.0</a>,&nbsp;<a href=\"https://ec.europa.eu/eusurvey/runner/SIQAT_v_2_1_0\">SIQAT v2.1.0</a>&nbsp;or&nbsp;</em><em><a href=\"https://ec.europa.eu/eusurvey/runner/GIQAT_v_2_1_0\">GIQAT </a><a href=\"https://ec.europa.eu/eusurvey/runner/GIQAT_v_2_1_0\">v2.1.0</a>.</em></p>\r\n\r\n<h2>The interoperability challenge</h2>\r\n\r\n<p><strong>Interoperability</strong> is more than a strategic priority on the political agenda. Today, it is expected to be <strong>standard practice </strong>in the day-to-day operations of public administrations. Public service owners are facing a number of <strong>challenges</strong> when it comes to delivering public services that are <strong>digital by default</strong>. These include:</p>\r\n\r\n<ul>\r\n\t<li>Improving interoperability of digital public services and bringing their <strong>maturity </strong>to a higher level;</li>\r\n\t<li>Optimising the <strong>customer experience </strong>by providing \u2018one-click\u2019 digital public services;</li>\r\n\t<li>Redesigning and standardising procedures to make digital public services <strong>more </strong><strong>efficient, </strong><strong>effective and transparent</strong></li>\r\n\t<li>Enabling <strong>seamless interaction </strong>of shared public services and promoting a culture of collaboration.</li>\r\n</ul>\r\n\r\n<p>Although the IATs are publicly available for any organisation and citizens interested,<strong>&nbsp;the main target audience is the public service owners of digital public services&nbsp;</strong>that operate in an environment where interoperability is required to deliver a public service to end users.</p>\r\n\r\n<p>Particularly the&nbsp;<strong>structural interoperability</strong>&nbsp;is assessed with&nbsp;<strong>SIQAT</strong>, the governance interoperability is assessed with&nbsp;<strong>GIQAT and the&nbsp;</strong>behavioural interoperability is assessed with&nbsp;<strong>IMAPS.</strong>&nbsp;Furthermore, each one of those solutions includes a set of questions that are assessing different interoperability aspects from a legal, organisational, semantic and technical interoperability viewpoint.</p>\r\n\r\n<p>The below image illustrates the different interoperability aspects in the digital public services context:</p>\r\n<img alt=\"interoperability_perspective\" data-align=\"center\" data-entity-type=\"file\" data-entity-uuid=\"fcd0936f-583c-4736-9443-6b5f8c8167ad\" data-image-style=\"wysiwyg_full_width\" height=\"369\" src=\"/sites/default/files/inline-images/interoperability%20perspective%20new_0.png\" width=\"920\" />\r\n<h2>What is <a href=\"https://joinup.ec.europa.eu/collection/imaps-interoperability-maturity-assessment-public-service/solution/siqat\">SIQAT</a>?</h2>\r\n\r\n<p>The&nbsp;<strong>Structural&nbsp;Interoperability</strong>&nbsp;<strong>Quick&nbsp;Assessment&nbsp;Toolkit (SIQAT\u00A9)</strong>&nbsp;has been developed in the context of Action 2016.36 Assessment of trans-European systems supporting EU policies of the Interoperability solutions&nbsp;and common frameworks for European public administrations, businesses and citizens (<a href=\"https://ec.europa.eu/isa2/isa2_en\">ISA2 programme</a>).&nbsp;</p>\r\n\r\n<p>The&nbsp;<strong>objective</strong>&nbsp;of the&nbsp;<strong>SIQAT\u00A9&nbsp;</strong>is to allows public service owners to evaluate the&nbsp;<strong>structural&nbsp;interoperability maturity level of their digital public service.&nbsp;</strong>The Structural Interoperability Quick Assessment Tool (SIQAT) which provides public administrations with insight into two key aspects of the structural&nbsp;interoperability of their digital public service:</p>\r\n\r\n<ul>\r\n\t<li><strong>Shareability:</strong>&nbsp;It is the extent that an open standard enables prospective coexistence of an off-the-shelf asset in a given domain set of digital public service value chains.</li>\r\n</ul>\r\n\r\n<ul>\r\n\t<li><strong>Reusability:</strong>&nbsp;It is the extent that an open standard enables the coexistence of an off-the-shelf asset in a given value chain of a digital public service.</li>\r\n</ul>\r\n\r\n<h2>What is <a href=\"https://joinup.ec.europa.eu/collection/interoperability-assessment-tools-iats-digital-public-services/solution/giqat\">GIQAT</a>?</h2>\r\n\r\n<p>The&nbsp;<strong>Governance&nbsp;Interoperability</strong>&nbsp;<strong>Quick&nbsp;Assessment&nbsp;Toolkit (GIQAT\u00A9)</strong>&nbsp;has been developed in the context of Action 2016.36 Assessment of trans-European systems supporting EU policies of the Interoperability solutions&nbsp;and common frameworks for European public administrations, businesses and citizens (<a href=\"https://ec.europa.eu/isa2/isa2_en\">ISA2 programme</a>).&nbsp;</p>\r\n\r\n<p>The&nbsp;<strong>objective</strong>&nbsp;of the&nbsp;<strong>GIQAT\u00A9&nbsp;</strong>is to allows public service owners to evaluate the&nbsp;<strong>governance interoperability maturity level of their digital public service.&nbsp;</strong>The Governance Interoperability Quick Assessment Tool (GIQAT) which provides public administrations with insight into two key aspects of the governance interoperability of their digital public service:</p>\r\n\r\n<ul>\r\n\t<li><strong>Collaboration Assurance:&nbsp;</strong>Is the extent that an open standard enables the collaboration assurance of a digital public service with another digital public service.</li>\r\n\t<li><strong>Collaboration Control:&nbsp;</strong>Is the extent that an open standard enables the collaboration control of a digital public service with another digital public service.</li>\r\n</ul>\r\n\r\n<h2>What is <a href=\"https://joinup.ec.europa.eu/collection/interoperability-assessment-tools-iats-digital-public-services/solution/imaps\">IMAPS</a>?</h2>\r\n\r\n<p>IMAPS is an online survey that helps public service owners evaluate, consider and improve <strong>all key interoperability aspects</strong> of their digital public service (legal, semantic, organisational, or technical). Ultimately, they can view and monitor the service\u2019s compliance with the <strong>New <a href=\"https://ec.europa.eu/isa2/eif_en\" target=\"_blank\">European Interoperability Framework (EIF)</a>.</strong></p>\r\n\r\n<p>Not only can IMAPS be used to assess the interoperability of <strong>any public service </strong>\u2013 from open data portals, and e-voting platforms, to public procurement services, and much more \u2013 it is applicable to services at <strong>all levels of government</strong> (international, national, regional and local).</p>\r\n\r\n<p>IMAPS looks at three <strong>different service areas</strong>&nbsp;(see IMAPS conceptual model below):</p>\r\n\r\n<ul>\r\n\t<li><strong>Service Delivery</strong> (D) \u2013 Delivery of the digital public service;</li>\r\n\t<li><strong>Service Consumption</strong> (C) \u2013 Consumption of reusable machine-to-machine services from other public administrations and businesses. This can include the consumption of functionalities, base registry information and security services;</li>\r\n\t<li><strong>Service Management </strong>(B) \u2013 Controlling and monitoring the process flow related to service interactions with the external domain from trigger to outcome. This area includes Service Management aspects such as enterprise architecture, procurement, and service level management.</li>\r\n</ul>\r\n<img alt=\"IMAPS_conceptual_model\" data-align=\"center\" data-entity-type=\"file\" data-entity-uuid=\"7c7928a6-d063-4ee7-aa2b-552f6cb33457\" data-image-style=\"wysiwyg_half_width\" height=\"717\" src=\"/sites/default/files/inline-images/IMAPS%20Conceptual%20model_0.png\" width=\"460\" />\r\n<h3>IATs define&nbsp;<strong>five levels of interoperability maturity</strong>:</h3>\r\n\r\n<ul>\r\n\t<li><strong>Ad hoc</strong><em>&nbsp;(level 1)</em>:&nbsp;Poor interoperability \u2013 the digital public service cannot be considered interoperable</li>\r\n\t<li><strong>Opportunistic&nbsp;</strong><em>(level 2)</em>:&nbsp;Fair interoperability \u2013 the digital public service implements some elements of interoperability best practices</li>\r\n\t<li><strong>Essential </strong><em>(level 3)</em>:&nbsp;Essential interoperability \u2013 the digital public service implements the essential best practices for interoperability</li>\r\n\t<li><strong>Sustainable</strong> <em>(level 4)</em>:&nbsp;Good interoperability \u2013 all relevant interoperability best practices are implemented by the digital public service</li>\r\n\t<li><strong>Seamless</strong> <em>(level 5)</em>:&nbsp;Interoperability leading practice \u2013 the digital public service is a leading interoperability practice example for others</li>\r\n</ul>\r\n<img alt=\"Interoperability maturity score\" data-align=\"center\" data-entity-type=\"file\" data-entity-uuid=\"9f2e2f8c-0ffe-4516-958a-af137e599605\" data-image-style=\"\" src=\"/sites/default/files/inline-images/MicrosoftTeams-image_3.png\" />\r\n<h2>Are they relevant for you?</h2>\r\n\r\n<p>You are involved in the design, development, management or delivery&nbsp;of a digital public service?</p>\r\n\r\n<p>IATs give you the tools to evaluate the interoperability maturity of your&nbsp;digital public service.</p>\r\n\r\n<p>IATs can be used at&nbsp;<strong>all government levels</strong>: national, regional, local and international.</p>\r\n\r\n<p><em>Discover the latest release of IMAPS&nbsp;(<a href=\"https://joinup.ec.europa.eu/collection/interoperability-assessment-tools-iats-digital-public-services/solution/imaps/release/v220\">v2.2.0</a>)&nbsp;and <strong>start your own assessment </strong>(<a href=\"https://ec.europa.eu/eusurvey/runner/IMAPS_v_2_2_0\">link</a> to&nbsp;online survey).</em></p>\r\n\r\n<p><em>Discover the latest release of SIQAT (<a href=\"https://joinup.ec.europa.eu/collection/interoperability-assessment-tools-iats-digital-public-services/solution/siqat/release/v210https://joinup.ec.europa.eu/collection/interoperability-assessment-tools-iats-digital-public-services/solution/siqat/release/v210\">v2.1.0</a>)&nbsp;and <strong>start your own assessment </strong>(<a href=\"https://ec.europa.eu/eusurvey/runner/SIQAT_v_2_1_0\">link</a> to&nbsp;online survey).</em></p>\r\n\r\n<p><em>Discover the latest release of GIQAT (<a href=\"https://joinup.ec.europa.eu/collection/interoperability-assessment-tools-iats-digital-public-services/solution/giqat/release/v210\">v2.1.0</a>)&nbsp;and <strong>start your own assessment </strong>(<a href=\"https://ec.europa.eu/eusurvey/runner/GIQAT_v_2_1_0\">link</a> to&nbsp;online survey).</em></p>\r\n\r\n<h2>What are the benefits of IATs?</h2>\r\n\r\n<p>IATs provide you with:</p>\r\n\r\n<ul>\r\n\t<li>A compact,&nbsp;highly user-friendly and free-of-charge&nbsp;<strong>online survey questionnaire,&nbsp;</strong>which can be completed in&nbsp;30 minutes;</li>\r\n\t<li>An<strong> interoperability maturity score </strong>that captures the current maturity level of your digital public service;</li>\r\n\t<li>A <strong>set of recommendations</strong> tailored to your digital public service&nbsp;for improving its interoperability maturity;</li>\r\n\t<li>A set of <strong>interoperability good practices</strong> and <strong>standards</strong>;</li>\r\n\t<li>A <strong>confirmation of conformance</strong> of your digital public service with the <a href=\"https://ec.europa.eu/isa2/eif_en\">European Interoperability Framework (EIF)</a>.</li>\r\n</ul>\r\n\r\n<h2>IMAPS Specialisations</h2>\r\n\r\n<p>The IMAPS action has also developed specialised versions of IMAPS, which enable public service owners to assess their digital public services in terms of their:</p>\r\n\r\n<ul>\r\n\t<li><strong>Legal Interoperability (<a href=\"https://joinup.ec.europa.eu/solution/limaps\">LIMAPS</a>)</strong>: the LIMAPS survey provides insights into&nbsp;legal interoperability aspects enabling the provision of a digital public service&nbsp;in a cross-border context and provides recommendations;</li>\r\n\t<li><strong>Organisational Interoperability (<a href=\"https://joinup.ec.europa.eu/solution/oimaps/about\">OIMAPS</a>)</strong>: the OIMAPS survey provides insights into organisational interoperability aspects enabling the provision&nbsp;of a digital public service&nbsp;in a cross-border context&nbsp;and provides recommendations;</li>\r\n\t<li><strong>Semantic Interoperability (<a href=\"https://joinup.ec.europa.eu/solution/simaps\">SIMAPS</a>)</strong>: the SIMAPS survey focuses on semantic interoperability aspects enabling the provision of a digital public service in a cross-border context and provides recommendations&nbsp;</li>\r\n\t<li><strong>Technical Interoperability (<a href=\"https://joinup.ec.europa.eu/solution/timaps/about\">TIMAPS</a>)</strong>: the TIMAPS survey focuses on technical interoperability aspects enabling the provision of a digital public service&nbsp;in a cross-border context and provides recommendations.&nbsp;</li>\r\n</ul>\r\n\r\n<p>All IMAPS specialisations are compliant&nbsp;with the latest version of the <a href=\"https://ec.europa.eu/isa2/eif_en\" target=\"_blank\">European Interoperability Framework (EIF)</a>.</p>\r\n\r\n<p>&nbsp;</p>\r\n\r\n<h2>How can we support your organisation in the uptake of IATs?</h2>\r\n\r\n<p>We organise <strong>knowledge transfer sessions </strong>with public administrations across Europe to support them in their assessments and their uptake of SIQAT, GIQAT and IMAPS specialisations. If you are interested in participating in an IATs knowledge transfer, please contact us via e-mail:&nbsp;<a href=\"DIGIT-IMAPS@ec.europa.eu\">DIGIT-IMAPS@ec.europa.eu</a>.</p>\r\n\r\n<h2>Insights</h2>\r\n\r\n<p>The team publishes a regular report which analyses&nbsp;the <strong>state of interoperability maturity of European digital public services</strong> which have been assessed with IATs.</p>\r\n\r\n<p>The latest version of the IMAPS report (<a href=\"https://joinup.ec.europa.eu/sites/default/files/document/2020-10/Report%20on%20IMAPS%20results%202020%20edition_0.pdf\">2020</a>) reveals that all of the digital public services assessed are on average below the Essential interoperability level (IMAPS maturity level 3).&nbsp;Up-to-date, IMAPS has been used by&nbsp;public administrations across Europe&nbsp;for assessing more than 200 digital public services.&nbsp;</p>\r\n\r\n<p>Discover the <strong>experience of other users</strong>&nbsp;<a href=\"https://joinup.ec.europa.eu/collection/imaps-interoperability-maturity-assessment-public-service/imaps-user-stories\">here</a>.</p>\r\n\r\n<h2>Context</h2>\r\n\r\n<p>IATs is an action of the <a href=\"https://joinup.ec.europa.eu/collection/interoperable-europe/interoperable-europe\">Interoperable Europe</a> public policy initiative under the <a href=\"https://digital-strategy.ec.europa.eu/en/library/digital-europe-programme-eu75-billion-funding-2021-2027\">Digital Europe programme</a>. The Digital Europe programme is designed to bridge&nbsp;the gap between digital technology research and market deployment. It will&nbsp;benefit Europe's citizens and businesses, especially SMEs. Investment&nbsp;under the Digital Europe Programme supports the European Union\u2019s twin objectives of a green transition and digital transformation while strengthening the Union\u2019s resilience and digital sovereignty. Modernising European public administrations and increasing their interoperability is an important contribution to the completion of the Digital Single Market, as one of the top 10 political priorities of the EU (<a href=\"https://ec.europa.eu/digital-single-market/en/digital-single-market\">https://ec.europa.eu/digital-single-market/en/digital-single-market</a>).</p>\r\n\r\n<h2>Release frequency and change management process</h2>\r\n\r\n<p>The <strong>frequency </strong>of a major release version for IATs, including incompatible changes, is released once per year.</p>\r\n\r\n<p><strong>New Change Requests</strong> (CR) for each one of the IATs questionnaires can be shared from the users via e-mail:&nbsp;<a href=\"DIGIT-IMAPS@ec.europa.eu\">DIGIT-IMAPS@ec.europa.eu</a>.</p>\r\n\r\n<p>The operational team receives each CR for IATs and describes it in a brief manner in the configuration checklist. Then, the team analyses the CR in the configuration checklist (e.g., CR Problem Statement, Key Risk identified with this CR, etc.) and registers it as a ticket in JIRA.&nbsp;The operational team requests for Project Officer's (PO) validation.</p>\r\n\r\n<p>If the PO validates the CR, the operational team plans its implementation as follows:</p>\r\n\r\n<ul>\r\n\t<li>In case the CR needs to be implemented immediately, the operational team shall implement it and the CR obtains the status \u201CImplemented\u201D;</li>\r\n\t<li>In case the CR does not need to be implemented immediately, the CR obtains the status \u201CPostponed\u201D and the operational team re-plans its implementation.</li>\r\n</ul>\r\n\r\n<p>Finally, the operational team deploys all CRs with the status \u201CImplemented\u201D in the EU Survey Portal in the respective tool (e.g., IMAPS, SIMAPS, GIQAT, etc.),&nbsp;updates the impacted element (e.g., Questionnaire, User guide, etc.) accordingly.</p>\r\n\r\n<p>In case the PO does not validate the CR, the CR will not be implemented.</p>\r\n\r\n<h2>How to contact us</h2>\r\n\r\n<p>In case of questions, please contact the IATs team via e-mail at&nbsp;<a href=\"mailto:DIGIT-IMAPS@ec.europa.eu\">DIGIT-IMAPS@ec.europa.eu</a>.</p>\r\n\r\n<h2>Useful material&nbsp;</h2>\r\n\r\n<p>Download the <a data-entity-type=\"file\" data-entity-uuid=\"38da9072-7826-4e7c-8fb7-d89e36f274c7\" href=\"/sites/default/files/inline-files/IATs%20Starter%20Guide_v1.00.pdf\">IATs starter guide</a>.</p>\r\n<img alt=\"IATs Starter guide\" data-align=\"center\" data-entity-type=\"file\" data-entity-uuid=\"c0f659c6-f340-4c5c-addc-d4c59527772b\" data-image-style=\"\" src=\"/sites/default/files/inline-images/IATs_Starter%20Guide_v1.00_0.png\" />\r\n<p>&nbsp;</p>\r\n"""@en .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/f1f76c60-db16-46c8-8df8-36064775305b> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/search>	"a:4:{s:6:\"fields\";a:3:{s:15:\"collection_type\";a:2:{s:6:\"weight\";s:1:\"0\";s:6:\"region\";s:3:\"top\";}s:21:\"collection_event_type\";a:2:{s:6:\"weight\";s:1:\"0\";s:6:\"region\";s:13:\"inline_facets\";}s:16:\"collection_topic\";a:2:{s:6:\"weight\";s:1:\"0\";s:6:\"region\";s:6:\"hidden\";}}s:7:\"enabled\";i:1;s:13:\"query_presets\";s:0:\"\";s:5:\"limit\";s:2:\"12\";}"^^<http://www.w3.org/2001/XMLSchema#string> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/7b90cdea-9343-43ed-b49f-ff62510f10a1> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/930aaef3-e02c-4836-a2ed-9d1a4e0a80b9> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"legal" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"interoperability assessment tools" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"semantic" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://purl.org/dc/terms/title>	"Interoperability Assessment Tools (IATs) for Digital Public Services"@en .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://purl.org/dc/terms/modified>	"2023-03-16T22:39:02+01:00"^^<http://www.w3.org/2001/XMLSchema#dateTime> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#contactPoint>	<http://data.europa.eu/w21/3d5ba686-c1b7-4618-bf70-dc16ab2dc1a1> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"limaps" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://joinup.eu/collection/moderation>	"false"^^<http://www.w3.org/2001/XMLSchema#boolean> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#dataset>	<http://data.europa.eu/w21/22514c30-2966-4820-8a88-11db42868ee8> .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://www.w3.org/ns/dcat#keyword>	"oimaps" .
<http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998>	<http://purl.org/dc/dcmitype/StillImage>	"613597"^^<http://www.w3.org/2001/XMLSchema#string> .
EOF;

  $query = <<<QUERY
WITH <http://joinup.eu/collection/published>
DELETE { <http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998> ?p ?o }
INSERT { $ntriples }
WHERE { <http://data.europa.eu/w21/abe7d0f7-8c41-465b-86c0-93d2f857f998> ?p ?o }
QUERY;

  \Drupal::getContainer()->get('sparql.endpoint')->update($query);
}

/**
 * Update the default user avatar image.
 */
function joinup_core_deploy_0109102(): void {
  \Drupal::classResolver(JoinupUserDefaultAvatarImageHelper::class)->createOrUpdate();
}
